@@ -29,7 +29,6 @@ mgga_x_rppscan_init(xc_func_type *p)
   p->params = libxc_malloc(sizeof(mgga_x_rppscan_params));
 }
 
-#include "decl_mgga.h"
 #include "maple2c/mgga_exc/mgga_x_rppscan.c"
 #include "work_mgga.c"
 
@@ -41,10 +40,10 @@ const xc_func_info_type xc_func_info_mgga_x_rppscan = {
   XC_EXCHANGE,
   "r++SCAN: rSCAN with uniform density limit and coordinate scaling behavior",
   XC_FAMILY_MGGA,
-  {&xc_ref_Furness2021, NULL, NULL, NULL, NULL},
+  {&xc_ref_Furness2022_034109, NULL, NULL, NULL, NULL},
   XC_FLAGS_3D | MAPLE2C_FLAGS,
   1e-11,
   {N_PAR, names, desc, par_rppscan, set_ext_params_cpy},
   mgga_x_rppscan_init, NULL,
-  NULL, NULL, work_mgga
+  NULL, NULL, &work_mgga
 };
