@@ -10,7 +10,6 @@
 
 #define XC_MGGA_X_TM          540 /* Tao and Mo 2016 exchange */
 
-#include "decl_mgga.h"
 #include "maple2c/mgga_exc/mgga_x_tm.c"
 #include "work_mgga.c"
 
@@ -27,5 +26,5 @@ const xc_func_info_type xc_func_info_mgga_x_tm = {
   1e-15,
   {0, NULL, NULL, NULL, NULL},
   NULL, NULL,
-  NULL, NULL, work_mgga,
+  NULL, NULL, &work_mgga,
 };
